# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.worker_event import WorkerEvent

class TestWorkerEvent(unittest.TestCase):
    """WorkerEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkerEvent:
        """Test WorkerEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkerEvent`
        """
        model = WorkerEvent()
        if include_optional:
            return WorkerEvent(
                type = '',
                sequence = 56,
                type_of = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                payload = perceptic_core_client.models.payload.payload(),
                requested_data = perceptic_core_client.models.requested_data.requestedData(),
                provided_data = perceptic_core_client.models.provided_data.providedData(),
                attribution = ''
            )
        else:
            return WorkerEvent(
        )
        """

    def testWorkerEvent(self):
        """Test WorkerEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.s3_connection_settings_api_dto import S3ConnectionSettingsApiDto

class TestS3ConnectionSettingsApiDto(unittest.TestCase):
    """S3ConnectionSettingsApiDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> S3ConnectionSettingsApiDto:
        """Test S3ConnectionSettingsApiDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `S3ConnectionSettingsApiDto`
        """
        model = S3ConnectionSettingsApiDto()
        if include_optional:
            return S3ConnectionSettingsApiDto(
                region = 'o',
                access_key = 'o',
                secret_key = 'o',
                url = 'o',
                type = ''
            )
        else:
            return S3ConnectionSettingsApiDto(
                region = 'o',
                access_key = 'o',
                secret_key = 'o',
                url = 'o',
        )
        """

    def testS3ConnectionSettingsApiDto(self):
        """Test S3ConnectionSettingsApiDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
